# Drv Pwr
This module enables to control Elektro Automatik power devices via SCPI commands.

Co-authors:
[Roberto Aldea](https://pypi.org/user/Raldea/), 
[Javier Sanz](https://pypi.org/user/javibu13/),
[Marius Crisan](https://pypi.org/user/mariuscrsn/)